@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from ...utils.util import validatePluginData, guessMetricByType
 
 class ClientModel(ABC):
     '''
@@ -61,3 +62,10 @@ class ClientModel(ABC):
         self.__legthCheck__(date_created)
         self.date_created = date_created
         self.__setitem__('date_created', self.date_created)
+
+    def validate(self):
+        validatePluginData(self.dict)
+    
+    def set_metric_types(self):
+        metric_units = guessMetricByType({}, self.dict)
+        self.__setitem__('units', metric_units)
