@@ -1,8 +1,8 @@
+from models.model import ClientModel
 import redis
-from abc import ABC, abstractmethod
 
-class RedisClient(ABC):
-    def __init__(self,host,port,db,charset="utf-8",decode_responses=True):
+class RedisClient(ClientModel):
+    def __init__(self, host, port, db, charset="utf-8", decode_responses=True, *args, **kwargs):
         self.host=host
         self.port=port
         self.db=db
@@ -15,6 +15,7 @@ class RedisClient(ABC):
             charset=self.charset,
             decode_responses=self.decode_responses
         )
+        super().__init__(*args, **kwargs)
 
     def set(
         self,
